Macro cassandra_cpp::stmt
source · macro_rules! stmt {
( $( $x:expr ),*) => { ... };
}Expand description
Create a Statement from a query string, automatically counting ?
characters to determine the number of parameters.
macro_rules! stmt {
( $( $x:expr ),*) => { ... };
}Create a Statement from a query string, automatically counting ?
characters to determine the number of parameters.