[][src]Struct cassandra_cpp::CassFuture

#[must_use]
pub struct CassFuture<T> { /* fields omitted */ }

A future representing the result of a Cassandra driver operation.

On success, returns a result of type T. On failure, returns a Cassandra error.

When constructing this take care to supply the correct type argument, since it will be used to control how the result is extracted from the underlying Cassandra driver future (see Completable).