Struct cassandra_cpp::CassResult [−][src]
pub struct CassResult(_);
The result of a query.
A result object is read-only and is thread-safe to read or iterate over
concurrently, since we do not bind any setters (e.g., set_metadata).
Implementations
impl CassResult[src]
impl CassResult[src]pub fn column_count(&self) -> u64[src]
pub fn column_count(&self) -> u64[src]Gets the number of columns per row for the specified result.
pub fn column_name(&self, index: usize) -> Result<&str>[src]
pub fn column_name(&self, index: usize) -> Result<&str>[src]Gets the column name at index for the specified result.
pub fn column_type(&self, index: usize) -> ValueType[src]
pub fn column_type(&self, index: usize) -> ValueType[src]Gets the column type at index for the specified result.
pub fn column_data_type(&self, index: usize) -> ConstDataType[src]
pub fn column_data_type(&self, index: usize) -> ConstDataType[src]Gets the column datatype at index for the specified result.
pub fn has_more_pages(&self) -> bool[src]
pub fn has_more_pages(&self) -> bool[src]Returns true if there are more pages.
pub fn paging_state_token(&self) -> Result<Option<Vec<u8>>>[src]
pub fn paging_state_token(&self) -> Result<Option<Vec<u8>>>[src]Gets the statement’s paging state. This can be used to get the next page of
data in a multi-page query, by using set_paging_state_token.
Returns:
Ok(None)if there are no more pages, and thus no paging state token.- `Ok(Some(Vec
)) if there are more pages, and a paging state token. Err(_)if there was an error getting the paging state token.