[−][src]Struct cassandra_cpp::KeyspaceMeta
A snapshot of the schema's metadata.
Methods
impl KeyspaceMeta[src]
ⓘImportant traits for AggregateIteratorpub fn aggregrates_iter(&self) -> AggregateIterator[src]
ⓘImportant traits for AggregateIterator
Iterator over the aggregates in this keyspace
ⓘImportant traits for FieldIteratorpub fn fields_iter(&self) -> FieldIterator[src]
ⓘImportant traits for FieldIterator
Iterator over the field in this keyspace
pub fn table_by_name(&self, name: &str) -> Option<TableMeta>[src]
Gets the table metadata for the provided table name.
pub fn user_type_by_name(&self, name: &str) -> Option<ConstDataType>[src]
Gets the data type for the provided type name.
pub fn get_function_by_name(
&self,
name: &str,
arguments: Vec<&str>
) -> Option<FunctionMeta>[src]
&self,
name: &str,
arguments: Vec<&str>
) -> Option<FunctionMeta>
Gets the function metadata for the provided function name.
pub fn aggregate_by_name(
&self,
name: &str,
arguments: Vec<&str>
) -> Option<AggregateMeta>[src]
&self,
name: &str,
arguments: Vec<&str>
) -> Option<AggregateMeta>
Gets the aggregate metadata for the provided aggregate name.
ⓘImportant traits for TableIteratorpub fn table_iter(&mut self) -> TableIterator[src]
ⓘImportant traits for TableIterator
Iterator over the tables in this keyspaces
ⓘImportant traits for FunctionIteratorpub fn function_iter(&mut self) -> FunctionIterator[src]
ⓘImportant traits for FunctionIterator
Iterator over the functions in this keyspaces
ⓘImportant traits for UserTypeIteratorpub fn user_type_iter(&mut self) -> UserTypeIterator[src]
ⓘImportant traits for UserTypeIterator
Iterator over the UDTs in this keyspaces
pub fn name(&self) -> String[src]
Gets the name of the keyspace.
pub fn field_by_name(&self, name: &str) -> Option<MetadataFieldValue>[src]
Gets a metadata field for the provided name. Metadata fields allow direct access to the column data found in the underlying "keyspaces" metadata table.