Struct cassandra_cpp::UserType

source ·
pub struct UserType(_);
A user defined type

Implementations

Gets the data type of a user defined type.

Sets a null in a user defined type at the specified index.

Sets a null in a user defined type at the specified name.

Sets a “tinyint” in a user defined type at the specified index.

Sets a “tinyint” in a user defined type at the specified name.

Sets an “smallint” in a user defined type at the specified index.

Sets an “smallint” in a user defined type at the specified name.

Sets an “int” in a user defined type at the specified index.

Sets an “int” in a user defined type at the specified name.

Sets a “date” in a user defined type at the specified index.

Sets a “date” in a user defined type at the specified name.

Sets an “bigint”, “counter”, “timestamp” or “time” in a user defined type at the specified index.

Sets an “bigint”, “counter”, “timestamp” or “time” in a user defined type at the specified name.

Sets a “float” in a user defined type at the specified index.

Sets a “float” in a user defined type at the specified name.

Sets an “double” in a user defined type at the specified index.

Sets an “double” in a user defined type at the specified name.

Sets a “boolean” in a user defined type at the specified index.

Sets a “boolean” in a user defined type at the specified name.

Sets an “ascii”, “text” or “varchar” in a user defined type at the specified index.

Sets an “ascii”, “text” or “varchar” in a user defined type at the specified name.

Sets a “blob” “varint” or “custom” in a user defined type at the specified index.

Sets a “blob”, “varint” or “custom” in a user defined type at the specified name.

Sets a “uuid” or “timeuuid” in a user defined type at the specified index.

Sets a “uuid” or “timeuuid” in a user defined type at the specified name.

Sets a “inet” in a user defined type at the specified index.

Sets a “inet” in a user defined type at the specified name.

Sets a list in a user defined type at the specified index.

Sets a list in a user defined type at the specified name.

Sets a map in a user defined type at the specified index.

Sets a map in a user defined type at the specified name.

Sets a “set” in a user defined type at the specified index.

Sets a “set” in a user defined type at the specified name.

Sets a “tuple” in a user defined type at the specified index.

Sets a “tuple” in a user defined type at the specified name.

Sets a user defined type in a user defined type at the specified index.

Sets a user defined type in a user defined type at the specified name.